@@ -4,8 +4,8 @@ from dataclasses import dataclass
 import sqlalchemy
 from sqlalchemy.ext.asyncio import create_async_engine, AsyncSession, AsyncEngine
 
-from async_tools import AsyncOnStart
-from async_tools import AsyncOnStop
+from async_tools import AsyncInitable, AsyncDeinitable
+
 
 from .abstract_database_connector import AbstractDatabaseConnector
 from ..entity_helpers.fields import get_value_tuple_by_columns, get_primary_key_columns
@@ -15,7 +15,7 @@ from ..entity_helpers.sqlalchemy_base import sqlalchemy_mapper_registry
 logger = logging.getLogger(__name__)
 
 
-class DatabaseConnector(AbstractDatabaseConnector, AsyncOnStart, AsyncOnStop):
+class DatabaseConnector(AbstractDatabaseConnector, AsyncInitable, AsyncDeinitable):
     @dataclass
     class Config:
         address: str
@@ -26,7 +26,10 @@ class DatabaseConnector(AbstractDatabaseConnector, AsyncOnStart, AsyncOnStop):
         echo: bool = False  # log all executed sql commands
 
     def __init__(self, config: Config):
+        AsyncInitable.__init__(self)
+        AsyncDeinitable.__init__(self)
         self._config = config
+        logger.info(f"{type(self).__name__} inited")
 
         logger.info(f'database address: {self._config.address}')
         schema_name_to_drivers = {
@@ -43,10 +46,10 @@ class DatabaseConnector(AbstractDatabaseConnector, AsyncOnStart, AsyncOnStop):
             address, echo=self._config.echo, pool_size=self._config.pool_size, max_overflow=self._config.max_overflow,
             pool_recycle=self._config.pool_recycle, pool_timeout=self._config.pool_timeout)
 
-    async def _on_start(self):
+    async def _async_init(self):
         await self.prepare_db(sqlalchemy_mapper_registry)
 
-    async def _on_stop(self):
+    async def _async_deinit(self):
         await self.engine.dispose()
 
     def get_session(self) -> AsyncSession:
